spannertools.get_spanners_that_cross_components
===============================================

.. autofunction:: abjad.tools.spannertools.get_spanners_that_cross_components.get_spanners_that_cross_components
